@@ -16,14 +16,14 @@ var _ PersistentState = &BoltPersistentState{}
 func TestBoltPersistentState(t *testing.T) {
 	chezmoitest.WithTestFS(t, nil, func(fileSystem vfs.FS) {
 		var (
-			s      = NewRealSystem(fileSystem)
-			path   = AbsPath("/home/user/.config/chezmoi/chezmoistate.boltdb")
+			system = NewRealSystem(fileSystem)
+			path   = NewAbsPath("/home/user/.config/chezmoi/chezmoistate.boltdb")
 			bucket = []byte("bucket")
 			key    = []byte("key")
 			value  = []byte("value")
 		)
 
-		b1, err := NewBoltPersistentState(s, path, BoltPersistentStateReadWrite)
+		b1, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
 		require.NoError(t, err)
 
 		// Test that getting a key from an non-existent state does not create
@@ -31,7 +31,7 @@ func TestBoltPersistentState(t *testing.T) {
 		actualValue, err := b1.Get(bucket, key)
 		require.NoError(t, err)
 		vfst.RunTests(t, fileSystem, "",
-			vfst.TestPath(string(path),
+			vfst.TestPath(path.String(),
 				vfst.TestDoesNotExist,
 			),
 		)
@@ -41,7 +41,7 @@ func TestBoltPersistentState(t *testing.T) {
 		// the state.
 		require.NoError(t, b1.Delete(bucket, key))
 		vfst.RunTests(t, fileSystem, "",
-			vfst.TestPath(string(path),
+			vfst.TestPath(path.String(),
 				vfst.TestDoesNotExist,
 			),
 		)
@@ -49,7 +49,7 @@ func TestBoltPersistentState(t *testing.T) {
 		// Test that setting a key creates the state.
 		assert.NoError(t, b1.Set(bucket, key, value))
 		vfst.RunTests(t, fileSystem, "",
-			vfst.TestPath(string(path),
+			vfst.TestPath(path.String(),
 				vfst.TestModeIsRegular,
 			),
 		)
@@ -76,7 +76,7 @@ func TestBoltPersistentState(t *testing.T) {
 
 		require.NoError(t, b1.Close())
 
-		b2, err := NewBoltPersistentState(s, path, BoltPersistentStateReadWrite)
+		b2, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
 		require.NoError(t, err)
 
 		require.NoError(t, b2.Delete(bucket, key))
@@ -90,15 +90,15 @@ func TestBoltPersistentState(t *testing.T) {
 func TestBoltPersistentStateMock(t *testing.T) {
 	chezmoitest.WithTestFS(t, nil, func(fileSystem vfs.FS) {
 		var (
-			s      = NewRealSystem(fileSystem)
-			path   = AbsPath("/home/user/.config/chezmoi/chezmoistate.boltdb")
+			system = NewRealSystem(fileSystem)
+			path   = NewAbsPath("/home/user/.config/chezmoi/chezmoistate.boltdb")
 			bucket = []byte("bucket")
 			key    = []byte("key")
 			value1 = []byte("value1")
 			value2 = []byte("value2")
 		)
 
-		b, err := NewBoltPersistentState(s, path, BoltPersistentStateReadWrite)
+		b, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
 		require.NoError(t, err)
 		require.NoError(t, b.Set(bucket, key, value1))
 
@@ -132,23 +132,23 @@ func TestBoltPersistentStateMock(t *testing.T) {
 func TestBoltPersistentStateReadOnly(t *testing.T) {
 	chezmoitest.WithTestFS(t, nil, func(fileSystem vfs.FS) {
 		var (
-			s      = NewRealSystem(fileSystem)
-			path   = AbsPath("/home/user/.config/chezmoi/chezmoistate.boltdb")
+			system = NewRealSystem(fileSystem)
+			path   = NewAbsPath("/home/user/.config/chezmoi/chezmoistate.boltdb")
 			bucket = []byte("bucket")
 			key    = []byte("key")
 			value  = []byte("value")
 		)
 
-		b1, err := NewBoltPersistentState(s, path, BoltPersistentStateReadWrite)
+		b1, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
 		require.NoError(t, err)
 		require.NoError(t, b1.Set(bucket, key, value))
 		require.NoError(t, b1.Close())
 
-		b2, err := NewBoltPersistentState(s, path, BoltPersistentStateReadOnly)
+		b2, err := NewBoltPersistentState(system, path, BoltPersistentStateReadOnly)
 		require.NoError(t, err)
 		defer b2.Close()
 
-		b3, err := NewBoltPersistentState(s, path, BoltPersistentStateReadOnly)
+		b3, err := NewBoltPersistentState(system, path, BoltPersistentStateReadOnly)
 		require.NoError(t, err)
 		defer b3.Close()
 
