@@ -25,10 +25,9 @@ func NewDebugSystem(system System) *DebugSystem {
 // Chmod implements System.Chmod.
 func (s *DebugSystem) Chmod(name AbsPath, mode fs.FileMode) error {
 	err := s.system.Chmod(name, mode)
-	log.Logger.Debug().
-		Str("name", string(name)).
+	log.Err(err).
+		Stringer("name", name).
 		Int("mode", int(mode)).
-		Err(err).
 		Msg("Chmod")
 	return err
 }
@@ -36,10 +35,9 @@ func (s *DebugSystem) Chmod(name AbsPath, mode fs.FileMode) error {
 // Glob implements System.Glob.
 func (s *DebugSystem) Glob(name string) ([]string, error) {
 	matches, err := s.system.Glob(name)
-	log.Logger.Debug().
+	log.Err(err).
 		Str("name", name).
 		Strs("matches", matches).
-		Err(err).
 		Msg("Glob")
 	return matches, err
 }
@@ -47,10 +45,9 @@ func (s *DebugSystem) Glob(name string) ([]string, error) {
 // IdempotentCmdCombinedOutput implements System.IdempotentCmdCombinedOutput.
 func (s *DebugSystem) IdempotentCmdCombinedOutput(cmd *exec.Cmd) ([]byte, error) {
 	output, err := s.system.IdempotentCmdCombinedOutput(cmd)
-	log.Logger.Debug().
+	log.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
-		Bytes("output", chezmoilog.FirstFewBytes(output)).
-		Err(err).
+		Bytes("output", chezmoilog.Output(output, err)).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("IdempotentCmdCombinedOutput")
 	return output, err
@@ -59,10 +56,9 @@ func (s *DebugSystem) IdempotentCmdCombinedOutput(cmd *exec.Cmd) ([]byte, error)
 // IdempotentCmdOutput implements System.IdempotentCmdOutput.
 func (s *DebugSystem) IdempotentCmdOutput(cmd *exec.Cmd) ([]byte, error) {
 	output, err := s.system.IdempotentCmdOutput(cmd)
-	log.Logger.Debug().
+	log.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
-		Bytes("output", chezmoilog.FirstFewBytes(output)).
-		Err(err).
+		Bytes("output", chezmoilog.Output(output, err)).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("IdempotentCmdOutput")
 	return output, err
@@ -71,9 +67,8 @@ func (s *DebugSystem) IdempotentCmdOutput(cmd *exec.Cmd) ([]byte, error) {
 // Lstat implements System.Lstat.
 func (s *DebugSystem) Lstat(name AbsPath) (fs.FileInfo, error) {
 	info, err := s.system.Lstat(name)
-	log.Logger.Debug().
-		Str("name", string(name)).
-		Err(err).
+	log.Err(err).
+		Stringer("name", name).
 		Msg("Lstat")
 	return info, err
 }
@@ -81,10 +76,9 @@ func (s *DebugSystem) Lstat(name AbsPath) (fs.FileInfo, error) {
 // Mkdir implements System.Mkdir.
 func (s *DebugSystem) Mkdir(name AbsPath, perm fs.FileMode) error {
 	err := s.system.Mkdir(name, perm)
-	log.Logger.Debug().
-		Str("name", string(name)).
+	log.Err(err).
+		Stringer("name", name).
 		Int("perm", int(perm)).
-		Err(err).
 		Msg("Mkdir")
 	return err
 }
@@ -97,9 +91,8 @@ func (s *DebugSystem) RawPath(path AbsPath) (AbsPath, error) {
 // ReadDir implements System.ReadDir.
 func (s *DebugSystem) ReadDir(name AbsPath) ([]fs.DirEntry, error) {
 	dirEntries, err := s.system.ReadDir(name)
-	log.Logger.Debug().
-		Str("name", string(name)).
-		Err(err).
+	log.Err(err).
+		Stringer("name", name).
 		Msg("ReadDir")
 	return dirEntries, err
 }
@@ -107,10 +100,9 @@ func (s *DebugSystem) ReadDir(name AbsPath) ([]fs.DirEntry, error) {
 // ReadFile implements System.ReadFile.
 func (s *DebugSystem) ReadFile(name AbsPath) ([]byte, error) {
 	data, err := s.system.ReadFile(name)
-	log.Logger.Debug().
-		Str("filename", string(name)).
-		Bytes("data", chezmoilog.FirstFewBytes(data)).
-		Err(err).
+	log.Err(err).
+		Stringer("name", name).
+		Bytes("data", chezmoilog.Output(data, err)).
 		Msg("ReadFile")
 	return data, err
 }
@@ -118,10 +110,9 @@ func (s *DebugSystem) ReadFile(name AbsPath) ([]byte, error) {
 // Readlink implements System.Readlink.
 func (s *DebugSystem) Readlink(name AbsPath) (string, error) {
 	linkname, err := s.system.Readlink(name)
-	log.Logger.Debug().
-		Str("name", string(name)).
+	log.Err(err).
+		Stringer("name", name).
 		Str("linkname", linkname).
-		Err(err).
 		Msg("Readlink")
 	return linkname, err
 }
@@ -129,9 +120,8 @@ func (s *DebugSystem) Readlink(name AbsPath) (string, error) {
 // RemoveAll implements System.RemoveAll.
 func (s *DebugSystem) RemoveAll(name AbsPath) error {
 	err := s.system.RemoveAll(name)
-	log.Logger.Debug().
-		Str("name", string(name)).
-		Err(err).
+	log.Err(err).
+		Stringer("name", name).
 		Msg("RemoveAll")
 	return err
 }
@@ -139,10 +129,9 @@ func (s *DebugSystem) RemoveAll(name AbsPath) error {
 // Rename implements System.Rename.
 func (s *DebugSystem) Rename(oldpath, newpath AbsPath) error {
 	err := s.system.Rename(oldpath, newpath)
-	log.Logger.Debug().
-		Str("oldpath", string(oldpath)).
-		Str("newpath", string(newpath)).
-		Err(err).
+	log.Err(err).
+		Stringer("oldpath", oldpath).
+		Stringer("newpath", newpath).
 		Msg("Rename")
 	return err
 }
@@ -150,9 +139,8 @@ func (s *DebugSystem) Rename(oldpath, newpath AbsPath) error {
 // RunCmd implements System.RunCmd.
 func (s *DebugSystem) RunCmd(cmd *exec.Cmd) error {
 	err := s.system.RunCmd(cmd)
-	log.Logger.Debug().
+	log.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
-		Err(err).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("RunCmd")
 	return err
@@ -161,9 +149,8 @@ func (s *DebugSystem) RunCmd(cmd *exec.Cmd) error {
 // RunIdempotentCmd implements System.RunIdempotentCmd.
 func (s *DebugSystem) RunIdempotentCmd(cmd *exec.Cmd) error {
 	err := s.system.RunIdempotentCmd(cmd)
-	log.Logger.Debug().
+	log.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
-		Err(err).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("RunIdempotentCmd")
 	return err
@@ -172,12 +159,11 @@ func (s *DebugSystem) RunIdempotentCmd(cmd *exec.Cmd) error {
 // RunScript implements System.RunScript.
 func (s *DebugSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, interpreter *Interpreter) error {
 	err := s.system.RunScript(scriptname, dir, data, interpreter)
-	log.Logger.Debug().
+	log.Err(err).
 		Str("scriptname", string(scriptname)).
-		Str("dir", string(dir)).
-		Bytes("data", chezmoilog.FirstFewBytes(data)).
+		Stringer("dir", dir).
+		Bytes("data", chezmoilog.Output(data, err)).
 		Object("interpreter", interpreter).
-		Err(err).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("RunScript")
 	return err
@@ -186,9 +172,8 @@ func (s *DebugSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, in
 // Stat implements System.Stat.
 func (s *DebugSystem) Stat(name AbsPath) (fs.FileInfo, error) {
 	info, err := s.system.Stat(name)
-	log.Logger.Debug().
-		Str("name", string(name)).
-		Err(err).
+	log.Err(err).
+		Stringer("name", name).
 		Msg("Stat")
 	return info, err
 }
@@ -201,11 +186,10 @@ func (s *DebugSystem) UnderlyingFS() vfs.FS {
 // WriteFile implements System.WriteFile.
 func (s *DebugSystem) WriteFile(name AbsPath, data []byte, perm fs.FileMode) error {
 	err := s.system.WriteFile(name, data, perm)
-	log.Logger.Debug().
-		Str("name", string(name)).
-		Bytes("data", chezmoilog.FirstFewBytes(data)).
+	log.Err(err).
+		Stringer("name", name).
+		Bytes("data", chezmoilog.Output(data, err)).
 		Int("perm", int(perm)).
-		Err(err).
 		Msg("WriteFile")
 	return err
 }
@@ -213,10 +197,9 @@ func (s *DebugSystem) WriteFile(name AbsPath, data []byte, perm fs.FileMode) err
 // WriteSymlink implements System.WriteSymlink.
 func (s *DebugSystem) WriteSymlink(oldname string, newname AbsPath) error {
 	err := s.system.WriteSymlink(oldname, newname)
-	log.Logger.Debug().
+	log.Err(err).
 		Str("oldname", oldname).
-		Str("newname", string(newname)).
-		Err(err).
+		Stringer("newname", newname).
 		Msg("WriteSymlink")
 	return err
 }
