@@ -5,8 +5,6 @@ import (
 	"os/exec"
 	"runtime"
 
-	"github.com/rs/zerolog/log"
-
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
@@ -24,7 +22,7 @@ func (e *GPGEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
 	var plaintext []byte
 	if err := withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
 		ciphertextAbsPath := tempDirAbsPath.Join(RelPath("ciphertext" + e.EncryptedSuffix()))
-		if err := os.WriteFile(string(ciphertextAbsPath), ciphertext, 0o600); err != nil {
+		if err := os.WriteFile(ciphertextAbsPath.String(), ciphertext, 0o600); err != nil {
 			return err
 		}
 		plaintextAbsPath := tempDirAbsPath.Join("plaintext")
@@ -35,7 +33,7 @@ func (e *GPGEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
 		}
 
 		var err error
-		plaintext, err = os.ReadFile(string(plaintextAbsPath))
+		plaintext, err = os.ReadFile(plaintextAbsPath.String())
 		return err
 	}); err != nil {
 		return nil, err
@@ -47,7 +45,7 @@ func (e *GPGEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
 func (e *GPGEncryption) DecryptToFile(plaintextFilename AbsPath, ciphertext []byte) error {
 	return withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
 		ciphertextAbsPath := tempDirAbsPath.Join(RelPath("ciphertext" + e.EncryptedSuffix()))
-		if err := os.WriteFile(string(ciphertextAbsPath), ciphertext, 0o600); err != nil {
+		if err := os.WriteFile(ciphertextAbsPath.String(), ciphertext, 0o600); err != nil {
 			return err
 		}
 		args := e.decryptArgs(plaintextFilename, ciphertextAbsPath)
@@ -60,7 +58,7 @@ func (e *GPGEncryption) Encrypt(plaintext []byte) ([]byte, error) {
 	var ciphertext []byte
 	if err := withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
 		plaintextAbsPath := tempDirAbsPath.Join("plaintext")
-		if err := os.WriteFile(string(plaintextAbsPath), plaintext, 0o600); err != nil {
+		if err := os.WriteFile(plaintextAbsPath.String(), plaintext, 0o600); err != nil {
 			return err
 		}
 		ciphertextAbsPath := tempDirAbsPath.Join(RelPath("ciphertext" + e.EncryptedSuffix()))
@@ -71,7 +69,7 @@ func (e *GPGEncryption) Encrypt(plaintext []byte) ([]byte, error) {
 		}
 
 		var err error
-		ciphertext, err = os.ReadFile(string(ciphertextAbsPath))
+		ciphertext, err = os.ReadFile(ciphertextAbsPath.String())
 		return err
 	}); err != nil {
 		return nil, err
@@ -91,7 +89,7 @@ func (e *GPGEncryption) EncryptFile(plaintextFilename AbsPath) ([]byte, error) {
 		}
 
 		var err error
-		ciphertext, err = os.ReadFile(string(ciphertextAbsPath))
+		ciphertext, err = os.ReadFile(ciphertextAbsPath.String())
 		return err
 	}); err != nil {
 		return nil, err
@@ -105,16 +103,16 @@ func (e *GPGEncryption) EncryptedSuffix() string {
 }
 
 func (e *GPGEncryption) decryptArgs(plaintextFilename, ciphertextFilename AbsPath) []string {
-	args := []string{"--output", string(plaintextFilename)}
+	args := []string{"--output", plaintextFilename.String()}
 	args = append(args, e.Args...)
-	args = append(args, "--decrypt", string(ciphertextFilename))
+	args = append(args, "--decrypt", ciphertextFilename.String())
 	return args
 }
 
 func (e *GPGEncryption) encryptArgs(plaintextFilename, ciphertextFilename AbsPath) []string {
 	args := []string{
 		"--armor",
-		"--output", string(ciphertextFilename),
+		"--output", ciphertextFilename.String(),
 	}
 	if e.Symmetric {
 		args = append(args, "--symmetric")
@@ -125,7 +123,7 @@ func (e *GPGEncryption) encryptArgs(plaintextFilename, ciphertextFilename AbsPat
 	if !e.Symmetric {
 		args = append(args, "--encrypt")
 	}
-	args = append(args, string(plaintextFilename))
+	args = append(args, plaintextFilename.String())
 	return args
 }
 
@@ -135,7 +133,7 @@ func (e *GPGEncryption) run(args []string) error {
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
-	return chezmoilog.LogCmdRun(log.Logger, cmd)
+	return chezmoilog.LogCmdRun(cmd)
 }
 
 // withPrivateTempDir creates a private temporary and calls f.
@@ -151,5 +149,5 @@ func withPrivateTempDir(f func(tempDirAbsPath AbsPath) error) error {
 		}
 	}
 
-	return f(AbsPath(tempDir))
+	return f(NewAbsPath(tempDir))
 }
