@@ -54,19 +54,20 @@ type templateConfig struct {
 // A Config represents a configuration.
 type Config struct {
 	// Global configuration, settable in the config file.
-	CacheDirAbsPath  chezmoi.AbsPath                 `mapstructure:"cacheDir"`
-	Color            autoBool                        `mapstructure:"color"`
-	Data             map[string]interface{}          `mapstructure:"data"`
-	DestDirAbsPath   chezmoi.AbsPath                 `mapstructure:"destDir"`
-	Interpreters     map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
-	Mode             chezmoi.Mode                    `mapstructure:"mode"`
-	Pager            string                          `mapstructure:"pager"`
-	Safe             bool                            `mapstructure:"safe"`
-	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
-	Template         templateConfig                  `mapstructure:"template"`
-	Umask            fs.FileMode                     `mapstructure:"umask"`
-	UseBuiltinAge    autoBool                        `mapstructure:"useBuiltinAge"`
-	UseBuiltinGit    autoBool                        `mapstructure:"useBuiltinGit"`
+	CacheDirAbsPath    chezmoi.AbsPath                 `mapstructure:"cacheDir"`
+	Color              autoBool                        `mapstructure:"color"`
+	Data               map[string]interface{}          `mapstructure:"data"`
+	DestDirAbsPath     chezmoi.AbsPath                 `mapstructure:"destDir"`
+	Interpreters       map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
+	Mode               chezmoi.Mode                    `mapstructure:"mode"`
+	Pager              string                          `mapstructure:"pager"`
+	Safe               bool                            `mapstructure:"safe"`
+	SourceDirAbsPath   chezmoi.AbsPath                 `mapstructure:"sourceDir"`
+	Template           templateConfig                  `mapstructure:"template"`
+	Umask              fs.FileMode                     `mapstructure:"umask"`
+	UseBuiltinAge      autoBool                        `mapstructure:"useBuiltinAge"`
+	UseBuiltinGit      autoBool                        `mapstructure:"useBuiltinGit"`
+	WorkingTreeAbsPath chezmoi.AbsPath                 `mapstructure:"workingTree"`
 
 	// Global configuration, not settable in the config file.
 	configFormat     readDataFormat
@@ -211,7 +212,7 @@ func newConfig(options ...configOption) (*Config, error) {
 
 	c := &Config{
 		// Global configuration, settable in the config file.
-		CacheDirAbsPath: chezmoi.AbsPath(bds.CacheHome).Join("chezmoi"),
+		CacheDirAbsPath: chezmoi.NewAbsPath(bds.CacheHome).Join("chezmoi"),
 		Color: autoBool{
 			auto: true,
 		},
@@ -530,12 +531,12 @@ func (c *Config) applyArgs(ctx context.Context, targetSystem chezmoi.System, tar
 
 func (c *Config) cmdOutput(dirAbsPath chezmoi.AbsPath, name string, args []string) ([]byte, error) {
 	cmd := exec.Command(name, args...)
-	if dirAbsPath != "" {
+	if !dirAbsPath.Empty() {
 		dirRawAbsPath, err := c.baseSystem.RawPath(dirAbsPath)
 		if err != nil {
 			return nil, err
 		}
-		cmd.Dir = string(dirRawAbsPath)
+		cmd.Dir = dirRawAbsPath.String()
 	}
 	return c.baseSystem.IdempotentCmdOutput(cmd)
 }
@@ -550,6 +551,101 @@ func (c *Config) colorAutoFunc() bool {
 	return false
 }
 
+// createAndReloadConfigFile creates a config file if it there is a config file
+// template and reloads it.
+func (c *Config) createAndReloadConfigFile() error {
+	// Find config template, execute it, and create config file.
+	configTemplateRelPath, ext, configTemplateContents, err := c.findConfigTemplate()
+	if err != nil {
+		return err
+	}
+	var configFileContents []byte
+	if configTemplateRelPath == "" {
+		if err := c.persistentState.Delete(chezmoi.ConfigStateBucket, configStateKey); err != nil {
+			return err
+		}
+	} else {
+		configFileContents, err = c.createConfigFile(configTemplateRelPath, configTemplateContents)
+		if err != nil {
+			return err
+		}
+
+		// Validate the config.
+		v := viper.New()
+		v.SetConfigType(ext)
+		if err := v.ReadConfig(bytes.NewBuffer(configFileContents)); err != nil {
+			return err
+		}
+		if err := v.Unmarshal(&Config{}, viperDecodeConfigOptions...); err != nil {
+			return err
+		}
+
+		// Write the config.
+		configPath := c.init.configPath
+		if c.init.configPath.Empty() {
+			configPath = chezmoi.NewAbsPath(c.bds.ConfigHome).Join("chezmoi").Join(configTemplateRelPath)
+		}
+		if err := chezmoi.MkdirAll(c.baseSystem, configPath.Dir(), 0o777); err != nil {
+			return err
+		}
+		if err := c.baseSystem.WriteFile(configPath, configFileContents, 0o600); err != nil {
+			return err
+		}
+
+		configStateValue, err := json.Marshal(configState{
+			ConfigTemplateContentsSHA256: chezmoi.HexBytes(chezmoi.SHA256Sum(configTemplateContents)),
+		})
+		if err != nil {
+			return err
+		}
+		if err := c.persistentState.Set(chezmoi.ConfigStateBucket, configStateKey, configStateValue); err != nil {
+			return err
+		}
+	}
+
+	// Reload config if it was created.
+	if configTemplateRelPath != "" {
+		viper.SetConfigType(ext)
+		if err := viper.ReadConfig(bytes.NewBuffer(configFileContents)); err != nil {
+			return err
+		}
+		if err := viper.Unmarshal(c, viperDecodeConfigOptions...); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+// createConfigFile creates a config file using a template and returns its
+// contents.
+func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte, error) {
+	funcMap := make(template.FuncMap)
+	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
+	chezmoi.RecursiveMerge(funcMap, map[string]interface{}{
+		"promptBool":    c.promptBool,
+		"promptInt":     c.promptInt,
+		"promptString":  c.promptString,
+		"stdinIsATTY":   c.stdinIsATTY,
+		"writeToStdout": c.writeToStdout,
+	})
+
+	t, err := template.New(string(filename)).Funcs(funcMap).Parse(string(data))
+	if err != nil {
+		return nil, err
+	}
+
+	sb := strings.Builder{}
+	templateData := c.defaultTemplateData()
+	if c.init.data {
+		chezmoi.RecursiveMerge(templateData, c.Data)
+	}
+	if err = t.Execute(&sb, templateData); err != nil {
+		return nil, err
+	}
+	return []byte(sb.String()), nil
+}
+
 // defaultConfigFile returns the default config file according to the XDG Base
 // Directory Specification.
 func (c *Config) defaultConfigFile(fileSystem vfs.Stater, bds *xdg.BaseDirectorySpecification) (chezmoi.AbsPath, error) {
@@ -557,11 +653,11 @@ func (c *Config) defaultConfigFile(fileSystem vfs.Stater, bds *xdg.BaseDirectory
 	for _, configDir := range bds.ConfigDirs {
 		configDirAbsPath, err := chezmoi.NewAbsPathFromExtPath(configDir, c.homeDirAbsPath)
 		if err != nil {
-			return "", err
+			return chezmoi.EmptyAbsPath, err
 		}
 		for _, extension := range viper.SupportedExts {
 			configFileAbsPath := configDirAbsPath.Join("chezmoi", chezmoi.RelPath("chezmoi."+extension))
-			if _, err := fileSystem.Stat(string(configFileAbsPath)); err == nil {
+			if _, err := fileSystem.Stat(configFileAbsPath.String()); err == nil {
 				return configFileAbsPath, nil
 			}
 		}
@@ -569,7 +665,7 @@ func (c *Config) defaultConfigFile(fileSystem vfs.Stater, bds *xdg.BaseDirectory
 	// Fallback to XDG Base Directory Specification default.
 	configHomeAbsPath, err := chezmoi.NewAbsPathFromExtPath(bds.ConfigHome, c.homeDirAbsPath)
 	if err != nil {
-		return "", err
+		return chezmoi.EmptyAbsPath, err
 	}
 	return configHomeAbsPath.Join("chezmoi", "chezmoi.toml"), nil
 }
@@ -633,17 +729,17 @@ func (c *Config) defaultSourceDir(fileSystem vfs.Stater, bds *xdg.BaseDirectoryS
 	for _, dataDir := range bds.DataDirs {
 		dataDirAbsPath, err := chezmoi.NewAbsPathFromExtPath(dataDir, c.homeDirAbsPath)
 		if err != nil {
-			return "", err
+			return chezmoi.EmptyAbsPath, err
 		}
 		sourceDirAbsPath := dataDirAbsPath.Join("chezmoi")
-		if _, err := fileSystem.Stat(string(sourceDirAbsPath)); err == nil {
+		if _, err := fileSystem.Stat(sourceDirAbsPath.String()); err == nil {
 			return sourceDirAbsPath, nil
 		}
 	}
 	// Fallback to XDG Base Directory Specification default.
 	dataHomeAbsPath, err := chezmoi.NewAbsPathFromExtPath(bds.DataHome, c.homeDirAbsPath)
 	if err != nil {
-		return "", err
+		return chezmoi.EmptyAbsPath, err
 	}
 	return dataHomeAbsPath.Join("chezmoi"), nil
 }
@@ -738,7 +834,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 			"kernel":       kernel,
 			"os":           runtime.GOOS,
 			"osRelease":    osRelease,
-			"sourceDir":    string(c.SourceDirAbsPath),
+			"sourceDir":    c.SourceDirAbsPath.String(),
 			"username":     username,
 			"version": map[string]interface{}{
 				"builtBy": c.versionInfo.BuiltBy,
@@ -839,6 +935,7 @@ func (c *Config) doPurge(purgeOptions *purgeOptions) error {
 		c.configFileAbsPath.Dir(),
 		c.configFileAbsPath,
 		persistentStateFileAbsPath,
+		c.WorkingTreeAbsPath,
 		c.SourceDirAbsPath,
 	}
 	if purgeOptions != nil && purgeOptions.binary {
@@ -846,7 +943,7 @@ func (c *Config) doPurge(purgeOptions *purgeOptions) error {
 		// Special case: do not purge the binary if it is a test binary created
 		// by go test as this would break later tests.
 		if err == nil && !strings.Contains(executable, "test") {
-			absPaths = append(absPaths, chezmoi.AbsPath(executable))
+			absPaths = append(absPaths, chezmoi.NewAbsPath(executable))
 		}
 	}
 
@@ -981,10 +1078,10 @@ func (c *Config) findConfigTemplate() (chezmoi.RelPath, string, []byte, error) {
 }
 
 func (c *Config) gitAutoAdd() (*git.Status, error) {
-	if err := c.run(c.SourceDirAbsPath, c.Git.Command, []string{"add", "."}); err != nil {
+	if err := c.run(c.WorkingTreeAbsPath, c.Git.Command, []string{"add", "."}); err != nil {
 		return nil, err
 	}
-	output, err := c.cmdOutput(c.SourceDirAbsPath, c.Git.Command, []string{"status", "--porcelain=v2"})
+	output, err := c.cmdOutput(c.WorkingTreeAbsPath, c.Git.Command, []string{"status", "--porcelain=v2"})
 	if err != nil {
 		return nil, err
 	}
@@ -1007,14 +1104,14 @@ func (c *Config) gitAutoCommit(status *git.Status) error {
 	if err := commitMessageTmpl.Execute(&commitMessage, status); err != nil {
 		return err
 	}
-	return c.run(c.SourceDirAbsPath, c.Git.Command, []string{"commit", "--message", commitMessage.String()})
+	return c.run(c.WorkingTreeAbsPath, c.Git.Command, []string{"commit", "--message", commitMessage.String()})
 }
 
 func (c *Config) gitAutoPush(status *git.Status) error {
 	if status.Empty() {
 		return nil
 	}
-	return c.run(c.SourceDirAbsPath, c.Git.Command, []string{"push"})
+	return c.run(c.WorkingTreeAbsPath, c.Git.Command, []string{"push"})
 }
 
 func (c *Config) makeRunEWithSourceState(runE func(*cobra.Command, []string, *chezmoi.SourceState) error) func(*cobra.Command, []string) error {
@@ -1064,6 +1161,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
 	persistentFlags.Var(&c.UseBuiltinAge, "use-builtin-age", "Use builtin age")
 	persistentFlags.Var(&c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
+	persistentFlags.VarP(&c.WorkingTreeAbsPath, "working-tree", "W", "Set working tree directory")
 	for viperKey, key := range map[string]string{
 		"color":         "color",
 		"destDir":       "destination",
@@ -1072,6 +1170,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		"sourceDir":     "source",
 		"useBuiltinAge": "use-builtin-age",
 		"useBuiltinGit": "use-builtin-git",
+		"workingTree":   "working-tree",
 	} {
 		if err := viper.BindPFlag(viperKey, persistentFlags.Lookup(key)); err != nil {
 			return nil, err
@@ -1132,7 +1231,6 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newImportCmd(),
 		c.newInitCmd(),
 		c.newInternalTestCmd(),
-		c.newMackupCmd(),
 		c.newManagedCmd(),
 		c.newMergeCmd(),
 		c.newPurgeCmd(),
@@ -1195,7 +1293,7 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 		// Warn the user of any errors reading the config file.
 		v := viper.New()
 		v.SetFs(afero.FromIOFS{FS: c.fileSystem})
-		v.SetConfigFile(string(c.configFileAbsPath))
+		v.SetConfigFile(c.configFileAbsPath.String())
 		err := v.ReadInConfig()
 		if err == nil {
 			err = v.Unmarshal(&Config{}, viperDecodeConfigOptions...)
@@ -1256,8 +1354,8 @@ func (c *Config) pageOutputString(output, cmdPager string) error {
 }
 
 func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error {
-	if c.cpuProfile != "" {
-		f, err := os.Create(string(c.cpuProfile))
+	if !c.cpuProfile.Empty() {
+		f, err := os.Create(c.cpuProfile.String())
 		if err != nil {
 			return err
 		}
@@ -1425,32 +1523,58 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 			// $XDG_DATA_DIR will fail. As a work-around, create the directory
 			// if it does not exist. See
 			// https://forum.snapcraft.io/t/wayland-dconf-and-xdg-runtime-dir/186/13.
-			if err := chezmoi.MkdirAll(c.baseSystem, chezmoi.AbsPath(c.bds.RuntimeDir), 0o700); err != nil {
+			if err := chezmoi.MkdirAll(c.baseSystem, chezmoi.NewAbsPath(c.bds.RuntimeDir), 0o700); err != nil {
 				return err
 			}
 		}
 	}
 
+	if c.WorkingTreeAbsPath.Empty() {
+		workingTreeAbsPath := c.SourceDirAbsPath
+	FOR:
+		for {
+			if info, err := c.baseSystem.Stat(workingTreeAbsPath.Join(".git")); err == nil && info.IsDir() {
+				c.WorkingTreeAbsPath = workingTreeAbsPath
+				break FOR
+			}
+			prevWorkingTreeDirAbsPath := workingTreeAbsPath
+			workingTreeAbsPath = workingTreeAbsPath.Dir()
+			if workingTreeAbsPath.Len() >= prevWorkingTreeDirAbsPath.Len() {
+				c.WorkingTreeAbsPath = c.SourceDirAbsPath
+				break FOR
+			}
+		}
+	}
+
+	if boolAnnotation(cmd, requiresWorkingTree) {
+		if _, err := c.SourceDirAbsPath.TrimDirPrefix(c.WorkingTreeAbsPath); err != nil {
+			return err
+		}
+		if err := chezmoi.MkdirAll(c.baseSystem, c.WorkingTreeAbsPath, 0o777); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
 func (c *Config) persistentStateFile() (chezmoi.AbsPath, error) {
-	if c.configFileAbsPath != "" {
+	if !c.configFileAbsPath.Empty() {
 		return c.configFileAbsPath.Dir().Join(persistentStateFilename), nil
 	}
 	for _, configDir := range c.bds.ConfigDirs {
 		configDirAbsPath, err := chezmoi.NewAbsPathFromExtPath(configDir, c.homeDirAbsPath)
 		if err != nil {
-			return "", err
+			return chezmoi.EmptyAbsPath, err
 		}
 		persistentStateFile := configDirAbsPath.Join("chezmoi", persistentStateFilename)
-		if _, err := os.Stat(string(persistentStateFile)); err == nil {
+		if _, err := os.Stat(persistentStateFile.String()); err == nil {
 			return persistentStateFile, nil
 		}
 	}
 	defaultConfigFileAbsPath, err := c.defaultConfigFile(c.fileSystem, c.bds)
 	if err != nil {
-		return "", err
+		return chezmoi.EmptyAbsPath, err
 	}
 	return defaultConfigFileAbsPath.Dir().Join(persistentStateFilename), nil
 }
@@ -1470,7 +1594,7 @@ func (c *Config) promptChoice(prompt string, choices []string) (string, error) {
 }
 
 func (c *Config) readConfig() error {
-	viper.SetConfigFile(string(c.configFileAbsPath))
+	viper.SetConfigFile(c.configFileAbsPath.String())
 	if c.configFormat != "" {
 		viper.SetConfigType(c.configFormat.String())
 	}
@@ -1501,12 +1625,12 @@ func (c *Config) readLine(prompt string) (string, error) {
 
 func (c *Config) run(dir chezmoi.AbsPath, name string, args []string) error {
 	cmd := exec.Command(name, args...)
-	if dir != "" {
+	if !dir.Empty() {
 		dirRawAbsPath, err := c.baseSystem.RawPath(dir)
 		if err != nil {
 			return err
 		}
-		cmd.Dir = string(dirRawAbsPath)
+		cmd.Dir = dirRawAbsPath.String()
 	}
 	cmd.Stdin = c.stdin
 	cmd.Stdout = c.stdout
@@ -1519,7 +1643,7 @@ func (c *Config) runEditor(args []string) error {
 		return err
 	}
 	editor, editorArgs := c.editor()
-	return c.run("", editor, append(editorArgs, args...))
+	return c.run(chezmoi.EmptyAbsPath, editor, append(editorArgs, args...))
 }
 
 func (c *Config) sourceAbsPaths(sourceState *chezmoi.SourceState, args []string) ([]chezmoi.AbsPath, error) {
@@ -1635,7 +1759,7 @@ func (c *Config) validateData() error {
 }
 
 func (c *Config) writeOutput(data []byte) error {
-	if c.outputAbsPath == "" || c.outputAbsPath == "-" {
+	if c.outputAbsPath.Empty() || c.outputAbsPath == chezmoi.NewAbsPath("-") {
 		_, err := c.stdout.Write(data)
 		return err
 	}
