@@ -10,7 +10,7 @@ import (
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	vfs "github.com/twpayne/go-vfs/v3"
+	vfs "github.com/twpayne/go-vfs/v4"
 	xdg "github.com/twpayne/go-xdg/v6"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
@@ -95,9 +95,7 @@ func TestParseConfig(t *testing.T) {
 			}, func(fileSystem vfs.FS) {
 				c := newTestConfig(t, fileSystem)
 				require.NoError(t, c.execute([]string{"init"}))
-				actualColor, err := c.Color.Value(c.colorAutoFunc)
-				assert.NoError(t, err)
-				assert.Equal(t, tc.expectedColor, actualColor)
+				assert.Equal(t, tc.expectedColor, c.Color.Value(c.colorAutoFunc))
 			})
 		})
 	}
