@@ -15,7 +15,6 @@ import (
 	"text/tabwriter"
 
 	"github.com/coreos/go-semver/semver"
-	"github.com/rs/zerolog/log"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/twpayne/go-shell"
@@ -150,6 +149,10 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 		&suspiciousEntriesCheck{
 			dirname: c.SourceDirAbsPath,
 		},
+		&dirCheck{
+			name:    "working-tree",
+			dirname: c.WorkingTreeAbsPath,
+		},
 		&dirCheck{
 			name:    "dest-dir",
 			dirname: c.DestDirAbsPath,
@@ -158,11 +161,13 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			name:       "shell",
 			binaryname: shell,
 			ifNotSet:   checkResultError,
+			ifNotExist: checkResultError,
 		},
 		&binaryCheck{
 			name:       "editor",
 			binaryname: editor,
 			ifNotSet:   checkResultWarning,
+			ifNotExist: checkResultWarning,
 		},
 		&umaskCheck{},
 		&binaryCheck{
@@ -228,7 +233,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 		},
 		&fileCheck{
 			name:       "keepassxc-db",
-			filename:   chezmoi.AbsPath(c.Keepassxc.Database),
+			filename:   chezmoi.NewAbsPath(c.Keepassxc.Database),
 			ifNotSet:   checkResultInfo,
 			ifNotExist: checkResultInfo,
 		},
@@ -310,7 +315,7 @@ func (c *binaryCheck) Run(system chezmoi.System) (checkResult, string) {
 	}
 
 	cmd := exec.Command(path, c.versionArgs...)
-	output, err := chezmoilog.LogCmdCombinedOutput(log.Logger, cmd)
+	output, err := chezmoilog.LogCmdCombinedOutput(cmd)
 	if err != nil {
 		return checkResultFailed, err.Error()
 	}
@@ -342,7 +347,7 @@ func (c *configFileCheck) Name() string {
 func (c *configFileCheck) Run(system chezmoi.System) (checkResult, string) {
 	filenames := chezmoi.NewStringSet()
 	for _, dir := range append([]string{c.bds.ConfigHome}, c.bds.ConfigDirs...) {
-		dirAbsPath := chezmoi.AbsPath(dir)
+		dirAbsPath := chezmoi.NewAbsPath(dir)
 		for _, extension := range viper.SupportedExts {
 			filename := dirAbsPath.Join(c.basename, chezmoi.RelPath(c.basename.String()+"."+extension))
 			if _, err := system.Stat(filename); err == nil {
@@ -358,7 +363,7 @@ func (c *configFileCheck) Run(system chezmoi.System) (checkResult, string) {
 		if filename != c.expected.String() {
 			return checkResultFailed, fmt.Sprintf("found %s, expected %s", filename, c.expected)
 		}
-		if _, err := system.ReadFile(chezmoi.AbsPath(filename)); err != nil {
+		if _, err := system.ReadFile(chezmoi.NewAbsPath(filename)); err != nil {
 			return checkResultError, fmt.Sprintf("%s: %v", filename, err)
 		}
 		return checkResultOK, filename
@@ -378,7 +383,7 @@ func (c *dirCheck) Name() string {
 
 func (c *dirCheck) Run(system chezmoi.System) (checkResult, string) {
 	if _, err := system.ReadDir(c.dirname); err != nil {
-		return checkResultError, fmt.Sprintf("%s: %v", c.dirname, err)
+		return checkResultError, err.Error()
 	}
 	return checkResultOK, fmt.Sprintf("%s is a directory", c.dirname)
 }
@@ -400,7 +405,7 @@ func (c *fileCheck) Name() string {
 }
 
 func (c *fileCheck) Run(system chezmoi.System) (checkResult, string) {
-	if c.filename == "" {
+	if c.filename.Empty() {
 		return c.ifNotSet, "not set"
 	}
 
@@ -424,7 +429,9 @@ func (osArchCheck) Run(system chezmoi.System) (checkResult, string) {
 	if osRelease, err := chezmoi.OSRelease(system); err == nil {
 		if name, ok := osRelease["NAME"].(string); ok {
 			if version, ok := osRelease["VERSION"].(string); ok {
-				fields = append(fields, "("+name+"/"+version+")")
+				fields = append(fields, "("+name+" "+version+")")
+			} else {
+				fields = append(fields, "("+name+")")
 			}
 		}
 	}
@@ -438,7 +445,7 @@ func (c *suspiciousEntriesCheck) Name() string {
 func (c *suspiciousEntriesCheck) Run(system chezmoi.System) (checkResult, string) {
 	// FIXME check that config file templates are in root
 	var suspiciousEntries []string
-	if err := chezmoi.WalkDir(system, c.dirname, func(absPath chezmoi.AbsPath, info fs.FileInfo, err error) error {
+	switch err := chezmoi.WalkDir(system, c.dirname, func(absPath chezmoi.AbsPath, info fs.FileInfo, err error) error {
 		if err != nil {
 			return err
 		}
@@ -450,7 +457,10 @@ func (c *suspiciousEntriesCheck) Run(system chezmoi.System) (checkResult, string
 			suspiciousEntries = append(suspiciousEntries, relPath)
 		}
 		return nil
-	}); err != nil {
+	}); {
+	case errors.Is(err, fs.ErrNotExist):
+		return checkResultOK, fmt.Sprintf("%s: no such file or directory", c.dirname)
+	case err != nil:
 		return checkResultError, err.Error()
 	}
 	if len(suspiciousEntries) > 0 {
